package F5::ClientSideJS;

use F5::DateTimeUtils;
use F5::Deploy;
use File::Copy;
use File::Path;

our $conf_output_tmp_dir = F5::Deploy::get_path_by_type('clientside_js') . '/tmp/';
our $conf_output_dir = F5::Deploy::get_path_by_type('clientside_js').'/trigger-queue/';


#----------------------------------------------------------------------

sub new {
    my($class, %params) = @_;
    my $self = {};
    bless $self, $class;
    $self->init(%params);
    return $self;
}

#----------------------------------------------------------------------

sub init {
    my($self, %params) = @_;
    $self->{logger} = $params{logger};
}

sub generate_obfuscation_config_file {
    my($self, %params) = @_;

    # First making sure required folders exists
    mkpath($conf_output_tmp_dir);
    mkpath($conf_output_dir);

    my $time_string = F5::DateTimeUtils::convert_epoch_to_file_timestamp(time);
    my $curr_filename = $conf_output_tmp_dir . 'obfuscator-' . $time_string . '.json';

    # if the output file exist, delete it before creating a new one
    if(-e $curr_filename){
        unlink $curr_filename;
    }

    my $rv = F5::SystemUtils::run_system_tool(command_line_params => 
                [ F5::Deploy::get_path_by_type('executables').'/datacrypt_cmd', '-g', $params{generated_variants_count}, '-o'.$curr_filename ]);

    if ($rv && !$rv->{completed_successfully}) {
        $self->{logger}->error("Failed to generate js obfuscation config file") if $self->{logger};    
        #die $rv->{standard_error};
        return;
    }

    # Copy created json file to shared volume
    move($curr_filename, $conf_output_dir);
    
    $self->{logger}->trace("Successfully generated js obfuscation config file in $curr_filename") if $self->{logger};
}

#----------------------------------------------------------------------

1;
